@@ -663,7 +663,7 @@ void MTPSlave::copy(const QUrl &src, const QUrl &dest, int, JobFlags flags)
 
                 // set correct modification time
                 struct ::utimbuf times;
-                times.actime = QDateTime::currentDateTime().toTime_t();
+                times.actime = QDateTime::currentDateTime().toSecsSinceEpoch();
                 times.modtime = source.modificationdate();
 
                 ::utime(dest.path().toUtf8().data(), &times);
@@ -855,7 +855,7 @@ void MTPSlave::fileSystemFreeSpace(const QUrl &url)
             }
         }
     }
-    error(KIO::ERR_COULD_NOT_STAT, url.toDisplayString());
+    error(KIO::ERR_CANNOT_STAT, url.toDisplayString());
 }
 
 int MTPSlave::waitForCopyOperation(const KMTPStorageInterface *storage)
